@@ -2,5 +2,5 @@ from django.apps import AppConfig
 
 
 class NewsletterConfig(AppConfig):
-    name = "newsletter"
+    name = "ycommon.django_modules.newsletter"
     default_auto_field = "django.db.models.AutoField"
